@@ -1,3 +1,3 @@
-from .client import HTTPClient, JsonRPCClient
+from .client import FlaskelHttp, HTTPClient, JsonRPCClient
 from .httpdumper import HTTPDumper
 from .useragent import UserAgent
