@@ -1,10 +1,12 @@
+import flask
 from requests import auth, exceptions as http_exc, request as send_request
 
-from flaskel.utils.datastuct import ObjectDict
+from flaskel import cap
+from flaskel.utils.datastruct import ObjectDict
 from flaskel.utils.faker import FakeLogger
 from flaskel.utils.uuid import get_uuid
 from . import http_status as httpcode
-from .httpdumper import HTTPDumper
+from .httpdumper import FlaskelHTTPDumper, HTTPDumper
 
 
 class HTTPTokenAuth(auth.AuthBase):
@@ -37,7 +39,7 @@ class HTTPTokenAuth(auth.AuthBase):
         :param r:
         :return:
         """
-        r.headers['Authorization'] = "Bearer {}".format(self.token)
+        r.headers['Authorization'] = f"Bearer {self.token}"
         return r
 
 
@@ -64,19 +66,15 @@ class HTTPBase(HTTPDumper):
 
 
 class HTTPClient(HTTPBase):
-    def __init__(self, endpoint, token=None, username=None, password=None,
-                 raise_on_exc=False, dump_body=False, logger=None):
+    def __init__(self, endpoint, token=None, username=None, password=None, **kwargs):
         """
 
         :param endpoint:
         :param token:
         :param username:
         :param password:
-        :param dump_body:
-        :param raise_on_exc:
-        :param logger:
         """
-        super().__init__(dump_body, raise_on_exc, logger)
+        super().__init__(**kwargs)
         self._endpoint = endpoint
         self._username = username
         self._password = password
@@ -106,17 +104,18 @@ class HTTPClient(HTTPBase):
         :return:
         """
         kwargs['auth'] = self.get_auth()
+        if dump_body is None:
+            dump_body = self._dump_body
         if kwargs.get('stream') is True:
             dump_body = False
 
         try:
-            url = "{}{}".format(self._endpoint, uri)
-            response = send_request(method, url, **kwargs)
+            response = send_request(method, f"{self._endpoint}{uri}", **kwargs)
             self._logger.info(self.dump_request(response.request))
         except (http_exc.ConnectionError, http_exc.Timeout) as exc:
             self._logger.exception(exc)
             if self._raise_on_exc:
-                raise
+                raise  # pragma: no cover
 
             return ObjectDict(dict(
                 body={},
@@ -149,49 +148,19 @@ class HTTPClient(HTTPBase):
         ))
 
     def get(self, uri, **kwargs):
-        """
-
-        :param uri:
-        :param kwargs:
-        :return:
-        """
         return self.request(uri, **kwargs)
 
     def post(self, uri, **kwargs):
-        """
-
-        :param uri:
-        :param kwargs:
-        :return:
-        """
-        return self.request(uri, 'POST', **kwargs)
+        return self.request(uri, method='POST', **kwargs)
 
     def put(self, uri, **kwargs):
-        """
-
-        :param uri:
-        :param kwargs:
-        :return:
-        """
-        return self.request(uri, 'PUT', **kwargs)
+        return self.request(uri, method='PUT', **kwargs)
 
     def patch(self, uri, **kwargs):
-        """
-
-        :param uri:
-        :param kwargs:
-        :return:
-        """
-        return self.request(uri, 'PATCH', **kwargs)
+        return self.request(uri, method='PATCH', **kwargs)
 
     def delete(self, uri, **kwargs):
-        """
-
-        :param uri:
-        :param kwargs:
-        :return:
-        """
-        return self.request(uri, 'DELETE', **kwargs)
+        return self.request(uri, method='DELETE', **kwargs)
 
 
 class JsonRPCClient(HTTPClient):
@@ -260,3 +229,12 @@ class JsonRPCClient(HTTPClient):
         )
 
         return ObjectDict(resp['body'] or {})
+
+
+class FlaskelHttp(HTTPClient, FlaskelHTTPDumper):
+    def request(self, uri, **kwargs):
+        if flask.request.id:
+            kwargs.setdefault('headers', {})
+            kwargs['headers'][cap.config.REQUEST_ID_HEADER] = flask.request.id
+
+        return super().request(uri, **kwargs)
