@@ -1,18 +1,15 @@
 import os
 
 import click
-import yaml
+import decouple
 
-from flaskel import AppFactory
-from flaskel.utils.misc import parse_value
-from flaskel.wsgi import BaseApplication, WSGIFactory
-
-wsgi_types = click.Choice(
-    WSGIFactory.WSGI_SERVERS.keys(),
-    case_sensitive=False
-)
+from . import AppBuilder
+from .utils.misc import parse_value
+from .utils.yaml import load_yaml_file, setup_yaml_parser
+from .wsgi import BaseApplication, WSGIFactory
 
 
+# noinspection PyUnusedLocal
 def option_as_dict(ctx, param, value):
     """
 
@@ -31,11 +28,11 @@ def option_as_dict(ctx, param, value):
 class Server:
     opt_config_attr = dict(
         default=None,
-        help='app yaml configuration file'
+        help='app yaml/json configuration file'
     )
     opt_log_config_attr = dict(
         default=None,
-        help='alternative log yaml configuration file'
+        help='alternative log yaml/json configuration file'
     )
     opt_bing_attr = dict(
         default='127.0.0.1:5000',
@@ -50,7 +47,10 @@ class Server:
     )
     opt_wsgi_server_attr = dict(
         default=None,
-        type=wsgi_types,
+        type=click.Choice(
+            WSGIFactory.WSGI_SERVERS.keys(),
+            case_sensitive=False
+        ),
         help='name of wsgi server to use'
     )
     option_wsgi_config_attr = dict(
@@ -61,7 +61,7 @@ class Server:
         help='wsgi configuration'
     )
 
-    def __init__(self, app_factory=AppFactory(), wsgi_factory=WSGIFactory()):
+    def __init__(self, app_factory=AppBuilder(), wsgi_factory=WSGIFactory()):
         """
 
         :param app_factory:
@@ -70,7 +70,7 @@ class Server:
         self._app_factory = app_factory
         self._wsgi_factory = wsgi_factory
 
-        assert isinstance(self._app_factory, AppFactory)
+        assert isinstance(self._app_factory, AppBuilder)
         assert isinstance(self._wsgi_factory, WSGIFactory)
 
     def _register_options(self, func):
@@ -108,28 +108,33 @@ class Server:
         return _forever()
 
     @staticmethod
-    def _prepare_config(filename, **kwargs):
+    def _prepare_config(filename, debug=None, bind=None, log_config=None):
         """
 
         :param filename:
         :return: config
         """
+        default_env = 'development' if debug else 'production'
+        env = decouple.config('FLASK_ENV', default=default_env)
+
         if filename is not None:
-            with open(filename) as f:
-                config = yaml.safe_load(f)
+            setup_yaml_parser()
+            config = load_yaml_file(filename)
+            if not config['app']['FLASK_ENV']:
+                config['app']['FLASK_ENV'] = env
         else:
-            env = os.environ.get('FLASK_ENV')
-            env = env or ('development' if kwargs['debug'] else 'production')
             config = dict(
-                app={'DEBUG': kwargs['debug'], 'ENV': env},
-                wsgi={'bind': kwargs['bind'], 'debug': kwargs['debug']}
+                app={'DEBUG': debug, 'FLASK_ENV': env},
+                wsgi={'bind': bind, 'debug': debug}
             )
 
-        if kwargs['log_config'] is not None:
-            config['app']['LOG_FILE_CONF'] = kwargs['log_config']
+        os.environ['FLASK_ENV'] = config['app']['FLASK_ENV']
+
+        if log_config is not None:
+            config['app']['LOG_FILE_CONF'] = log_config
 
         # debug flag enabled overrides config file
-        if kwargs['debug'] is True:
+        if debug is True:
             config['app']['DEBUG'] = True
 
         return config
