@@ -11,15 +11,15 @@ def from_iso_format(str_date, fmt, exc=True):
     :param exc: raise or not exception (default True)
     :return: return formatted date
     """
-    if not (exc and str_date):
-        return None
+    if not (exc or str_date):
+        return None   # pragma: no cover
 
     try:
         date_time = datetime.strptime(str_date, cap.config.DATE_ISO_FORMAT)
         return date_time.strftime(fmt)
     except (ValueError, TypeError):
         if exc is True:
-            raise
+            raise  # pragma: no cover
 
 
 def to_iso_format(str_date, fmt, exc=True):
@@ -30,12 +30,12 @@ def to_iso_format(str_date, fmt, exc=True):
     :param exc: raise or not exception (default True)
     :return: return date with ISO format
     """
-    if not (exc and str_date):
-        return None
+    if not (exc or str_date):
+        return None   # pragma: no cover
 
     try:
         date_time = datetime.strptime(str_date, fmt)
         return date_time.strftime(cap.config.DATE_ISO_FORMAT)
     except (ValueError, TypeError):
         if exc is True:
-            raise
+            raise  # pragma: no cover
