@@ -1,12 +1,9 @@
-__version__ = '1.2.0'
+__version__ = '1.2.5'
 
 __author_name__ = 'cs91chris'
 __author_email__ = 'cs91chris@voidbrain.me'
 
-__author__ = "{} <{}>".format(
-    __author_name__,
-    __author_email__
-)
+__author__ = f"{__author_name__} <{__author_email__}>"
 
 __all__ = [
     '__version__',
